@@ -11,7 +11,7 @@ https://chromedriver.chromium.org/downloads
 可修改配置：
 option: 浏览器的配置项，使用方式同webdriver.ChromeOptions，仅是其实例
     option还包含两个可配置项os_,pypath
-    option.os_=xxx 标识xxx为当前使用的系统，可填写参数“win”，“linux”，“mac”，当不填入视为自动获取
+    option.os_=xxx 标识xxx为当前使用的系统，可填写参数“win”，“linux”，“mac”，"mac_m1"当不填入视为自动获取
     option.pypath=xxx 标识xxx为当前python根目录，必须是一个系统绝对路径，链接python根目录
 导入使用：
 使用driver：
@@ -106,8 +106,10 @@ def __updata_driver(my_version, use_os):
             my_os = 'chromedriver_win32.zip'
         elif use_os == 'mac':
             my_os = 'chromedriver_mac64.zip'
+        elif use_os == 'mac_m1':
+            my_os = 'chromedriver_mac64_m1.zip'
         else:
-            raise ValueError('输入的系统名称不正确！仅支持 win、 linux、 mac')
+            raise ValueError('输入的系统名称不正确！仅支持 win、 linux、 mac, mac_m1')
         find_driver = __choose_driver(my_version)
         if len(find_driver) == 0:
             raise ValueError('未找到相关driver文件')
@@ -122,6 +124,7 @@ def __updata_driver(my_version, use_os):
             f.write(res.content)
         # Logger.success(f'成功下载chromedriver文件，版本<{version_driver}>')
         print(f'\033[1;50;32m成功下载chromedriver文件，版本<{version_driver}>\033[0m')
+        return version_driver
     except ValueError as v:
         print(f'\033[1;50;31m{v}\033[0m')
 
@@ -222,7 +225,7 @@ def driver(*args, **kwargs):
                     if option.os_ == '':
                         __get_system()
                     else:
-                        if option.os_ not in ('win', 'linux', 'mac'):
+                        if option.os_ not in ('win', 'linux', 'mac', 'mac_m1'):
                             raise Exception('输入的系统名称有误，参数为win、linux、mac')
                         else:
                             print(f'\033[1;50;32m当前为手动配置系统<{option.os_}>\033[0m')
@@ -233,11 +236,14 @@ def driver(*args, **kwargs):
                             print(f'\033[1;50;32m当前为手动配置的python路径：{option.pypath}\033[0m')
                         else:
                             raise Exception('当前路径不是指向的一个文件夹，或者路径不存在')
-                    __updata_driver(chrome_version, option.os_)
-                    __unzip_file(f'driver-{chrome_version}.zip')
-                    __move_file(option.pypath)
-                    Path(f'driver-{chrome_version}.zip').unlink(missing_ok=True)
-                    Path('chromedriver.exe').unlink(missing_ok=True)
+                    version = __updata_driver(chrome_version, option.os_)
+                    if version:
+                        __unzip_file(f'driver-{version}.zip')
+                        __move_file(option.pypath)
+                        Path(f'driver-{chrome_version}.zip').unlink(missing_ok=True)
+                        Path('chromedriver.exe').unlink(missing_ok=True)
+                    else:
+                        raise Exception("未获取到driver版本名称")
                 else:
                     raise Exception('获取chrome版本失败，代码停止运行')
                 return webdriver.Chrome(*args, **kwargs, options=option)
